module Tracker
  class Deliverer
    attr_reader :project, :git
    def initialize(project, git)
      @project = project
      @git = git
    end

    def mark_as_delivered(branch = nil, server_name = nil)
      options = {}
      options[:branch] = branch if branch

      collection = project.finished

      collection.each do |story|
        puts "Found finished story in Pivotal with id #{story.id}"
        if git.contains?(story.id, options)
          puts "Delivering story with id #{story.id} on server #{server_name}"
          project.deliver(story)
          project.comment(story, server_name) if server_name
        end
      end
    end

    def find_and_comment(branch = nil, server_name = nil, version = nil)
      options = {}
      options[:branch] = branch if branch

      for story_id in git.latest_log(options)
        story = project.find(story_id)
        if story
          puts "Found story with id #{story_id} on server #{server_name}"
          project.comment(story, server_name)
          project.add_label(story, version) if version
        end
      end
    end
  end
end
