require 'pivotal-tracker'

module Tracker
  class Project

    attr_reader :tracker_token, :project_id

    def initialize(tracker_token, project_id)
      @tracker_token = tracker_token
      @project_id = project_id

      PivotalTracker::Client.token = tracker_token
      PivotalTracker::Client.use_ssl = true
    end

    def find(story_id)
      _project.stories.find(story_id)
    end

    def finished
      _project.stories.all(state: 'finished', story_type: ['bug', 'feature'])
    end

    def delivered
      _project.stories.all(state: 'delivered', story_type: ['bug', 'feature'])
    end

    def deliver(story)
      story.update(current_state: 'delivered')
    end

    def accept(story)
      story.update(current_state: 'accepted')
    end

    def add_label(story, label)
      labels = (story.labels || '').split(',')
      unless labels.any?{|label| label =~ /^v[0-9]+\.[0-9]+\.[0-9]+$/}
        labels << label
        story.update(labels: labels.join(','))
      end
    end

    def comment(story, server_name)
      msg = "Delivered by script to #{server_name}"

      unless story.notes.all.any?{|note| note.text == msg}
        story.notes.create(:text => msg)
      end
    end

    private
    def _project
      @project ||= PivotalTracker::Project.find(project_id)
    end
  end
end
